@@ -1,18 +1,17 @@
-## Copyright (C) 2008  Francesco Potort  <pot@gnu.org>
+## Copyright (C) 2008 Francesco Potort <pot@gnu.org>
 ##
-## This software is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 3, or (at your option)
-## any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This software is distributed in the hope that it will be useful, but
-## WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-## General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this software; see the file COPYING.  If not, see
-## <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{y} =} linkage (@var{d})
@@ -217,6 +216,7 @@ endfunction
 %!assert (cond (linkage (pdist (x), "complete")),  21.793345,t);
 %!assert (cond (linkage (pdist (x), "average")),   27.045012,t);
 %!assert (cond (linkage (pdist (x), "weighted")),  27.412889,t);
+%! lastwarn(); # Clear last warning before the test
 %!warning <monotonically> linkage (pdist (x), "centroid");
 %!test warning off clustering
 %! assert (cond (linkage (pdist (x), "centroid")), 27.457477,t);
