@@ -1,17 +1,17 @@
 ## Copyright (C) 2003 Iain Murray
 ##
-## This program is free software; you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2 of the License, or
-## (at your option) any later version.
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 3 of the License, or (at your option) any later
+## version.
 ##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
 ##
-## You should have received a copy of the GNU General Public License
-## along with this program; If not, see <http://www.gnu.org/licenses/>.
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} @var{s} = mvnrnd (@var{mu}, @var{Sigma})
@@ -63,17 +63,17 @@ endfunction
 % {{{ END OF CODE --- Guess I should provide an explanation:
 % 
 % We can draw from axis aligned unit Gaussians with randn(d)
-% 	x ~ A*exp(-0.5*x'*x)
+%   x ~ A*exp(-0.5*x'*x)
 % We can then rotate this distribution using
-% 	y = U'*x
+%   y = U'*x
 % Note that
-% 	x = inv(U')*y
+%   x = inv(U')*y
 % Our new variable y is distributed according to:
-% 	y ~ B*exp(-0.5*y'*inv(U'*U)*y)
+%   y ~ B*exp(-0.5*y'*inv(U'*U)*y)
 % or
-% 	y ~ N(0,Sigma)
+%   y ~ N(0,Sigma)
 % where
-% 	Sigma = U'*U
+%   Sigma = U'*U
 % For a given Sigma we can use the chol function to find the corresponding U,
 % draw x and find y. We can adjust for a non-zero mean by just adding it on.
 % 
@@ -85,11 +85,11 @@ endfunction
 % another way of doing the decomposition is by diagonalising Sigma (which is
 % slower but works).
 % if
-% 	[E,Lambda]=eig(Sigma)
+%   [E,Lambda]=eig(Sigma)
 % then
-% 	Sigma = E*Lambda*E'
+%   Sigma = E*Lambda*E'
 % so
-% 	U = sqrt(Lambda)*E'
+%   U = sqrt(Lambda)*E'
 % If any Lambdas are negative then Sigma just isn't even positive semi-definite
 % so we can give up.
 %
