@@ -1,3 +1,6 @@
+## Author: Paul Kienzle <pkienzle@users.sf.net>
+## This program is granted to the public domain.
+
 ## -*- texinfo -*-
 ## @deftypefn {Function File} normplot (@var{X})
 ##
@@ -12,9 +15,6 @@
 ## need to be cleared before subsequent graphs using 'clf'.
 ## @end deftypefn
 
-# Author: Paul Kienzle <pkienzle@users.sf.net>
-# This program is in the public domain
-
 function normplot(X)
   if nargin!=1, print_usage; end
   if (rows(X) == 1), X=X(:); end
