@@ -1,3 +1,6 @@
+## Author: Paul Kienzle <pkienzle@users.sf.net>
+## This program is granted to the public domain.
+
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {[@var{pc}, @var{z}, @var{w}, @var{Tsq}] =} princomp (@var{X})
 ##
@@ -9,9 +12,6 @@
 ## statistic for the transformed data.
 ## @end deftypefn
 
-## Author: Paul Kienzle
-## This program is public domain.
-
 function [pc,z,w,Tsq] = princomp(X)
   C = cov(X);
   [U,D,pc] = svd(C,1);
